@@ -43,8 +43,9 @@ func init() {
 		Description: "Uptobox",
 		NewFs:       NewFs,
 		Options: []fs.Option{{
-			Help: "Your access token.\n\nGet it from https://uptobox.com/my_account.",
-			Name: "access_token",
+			Help:      "Your access token.\n\nGet it from https://uptobox.com/my_account.",
+			Name:      "access_token",
+			Sensitive: true,
 		}, {
 			Help:     "Set to make uploaded files private",
 			Name:     "private",
@@ -245,7 +246,7 @@ func NewFs(ctx context.Context, name string, root string, config configmap.Mappe
 	return f, nil
 }
 
-func (f *Fs) decodeError(resp *http.Response, response interface{}) (err error) {
+func (f *Fs) decodeError(resp *http.Response, response any) (err error) {
 	defer fs.CheckClose(resp.Body, &err)
 
 	body, err := io.ReadAll(resp.Body)
