@@ -34,7 +34,7 @@ not), the modification time (if known, the current time if not), the
 number of objects in the directory (if known, -1 if not) and the name
 of the directory, E.g.
 
-` + "```sh" + `
+` + "```console" + `
 $ rclone lsd swift:
       494000 2018-04-26 08:43:20     10000 10000files
           65 2018-04-26 08:43:20         1 1File
@@ -42,7 +42,7 @@ $ rclone lsd swift:
 
 Or
 
-` + "```sh" + `
+` + "```console" + `
 $ rclone lsd drive:test
           -1 2016-10-17 17:41:53        -1 1000files
           -1 2017-01-03 14:40:54        -1 2500files
