@@ -53,8 +53,8 @@ var commandDefinition = &cobra.Command{
 	Short: `Run a command against a running rclone.`,
 	Long: strings.ReplaceAll(`This runs a command against a running rclone.  Use the |--url| flag to
 specify an non default URL to connect on.  This can be either a
-":port" which is taken to mean "http://localhost:port" or a
-"host:port" which is taken to mean "http://host:port"
+":port" which is taken to mean <http://localhost:port> or a
+"host:port" which is taken to mean <http://host:port>.
 
 A username and password can be passed in with |--user| and |--pass|.
 
@@ -63,10 +63,12 @@ Note that |--rc-addr|, |--rc-user|, |--rc-pass| will be read also for
 
 The |--unix-socket| flag can be used to connect over a unix socket like this
 
-    # start server on /tmp/my.socket
-    rclone rcd --rc-addr unix:///tmp/my.socket
-    # Connect to it
-    rclone rc --unix-socket /tmp/my.socket core/stats
+|||sh
+# start server on /tmp/my.socket
+rclone rcd --rc-addr unix:///tmp/my.socket
+# Connect to it
+rclone rc --unix-socket /tmp/my.socket core/stats
+|||
 
 Arguments should be passed in as parameter=value.
 
@@ -81,29 +83,38 @@ options in the form |-o key=value| or |-o key|. It can be repeated as
 many times as required. This is useful for rc commands which take the
 "opt" parameter which by convention is a dictionary of strings.
 
-    -o key=value -o key2
+|||text
+-o key=value -o key2
+|||
 
 Will place this in the "opt" value
 
-    {"key":"value", "key2","")
-
+|||json
+{"key":"value", "key2","")
+|||
 
 The |-a|/|--arg| option can be used to set strings in the "arg" value. It
 can be repeated as many times as required. This is useful for rc
 commands which take the "arg" parameter which by convention is a list
 of strings.
 
-    -a value -a value2
+|||text
+-a value -a value2
+|||
 
 Will place this in the "arg" value
 
-    ["value", "value2"]
+|||json
+["value", "value2"]
+|||
 
 Use |--loopback| to connect to the rclone instance running |rclone rc|.
 This is very useful for testing commands without having to run an
 rclone rc server, e.g.:
 
-    rclone rc --loopback operations/about fs=/
+|||sh
+rclone rc --loopback operations/about fs=/
+|||
 
 Use |rclone rc| to see a list of all possible commands.`, "|", "`"),
 	Annotations: map[string]string{
