@@ -6,6 +6,7 @@ package sftp
 import (
 	"context"
 	"fmt"
+	"strings"
 
 	"github.com/rclone/rclone/cmd"
 	"github.com/rclone/rclone/cmd/serve"
@@ -146,11 +147,13 @@ reachable externally then supply ` + "`--addr :2022`" + ` for example.
 This also supports being run with socket activation, in which case it will
 listen on the first passed FD.
 It can be configured with .socket and .service unit files as described in
-https://www.freedesktop.org/software/systemd/man/latest/systemd.socket.html
+<https://www.freedesktop.org/software/systemd/man/latest/systemd.socket.html>.
 
 Socket activation can be tested ad-hoc with the ` + "`systemd-socket-activate`" + `command:
 
-	systemd-socket-activate -l 2222 -- rclone serve sftp :local:vfs/
+` + "```console" + `
+systemd-socket-activate -l 2222 -- rclone serve sftp :local:vfs/
+` + "```" + `
 
 This will socket-activate rclone on the first connection to port 2222 over TCP.
 
@@ -160,7 +163,9 @@ sftp backend, but it may not be with other SFTP clients.
 If ` + "`--stdio`" + ` is specified, rclone will serve SFTP over stdio, which can
 be used with sshd via ~/.ssh/authorized_keys, for example:
 
-    restrict,command="rclone serve sftp --stdio ./photos" ssh-rsa ...
+` + "```text" + `
+restrict,command="rclone serve sftp --stdio ./photos" ssh-rsa ...
+` + "```" + `
 
 On the client you need to set ` + "`--transfers 1`" + ` when using ` + "`--stdio`" + `.
 Otherwise multiple instances of the rclone server are started by OpenSSH
@@ -173,7 +178,7 @@ used. Omitting "restrict" and using  ` + "`--sftp-path-override`" + ` to enable
 checksumming is possible but less secure and you could use the SFTP server
 provided by OpenSSH in this case.
 
-` + vfs.Help() + proxy.Help,
+` + strings.TrimSpace(vfs.Help()+proxy.Help),
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.48",
 		"groups":            "Filter",
