@@ -107,7 +107,7 @@ browser, or you can make a remote of type WebDAV to read and write it.
 
 ### WebDAV options
 
-#### --etag-hash 
+#### --etag-hash
 
 This controls the ETag header.  Without this flag the ETag will be
 based on the ModTime and Size of the object.
@@ -119,44 +119,58 @@ to see the full list.
 
 ### Access WebDAV on Windows
 
-WebDAV shared folder can be mapped as a drive on Windows, however the default settings prevent it.
-Windows will fail to connect to the server using insecure Basic authentication.
-It will not even display any login dialog. Windows requires SSL / HTTPS connection to be used with Basic.
-If you try to connect via Add Network Location Wizard you will get the following error:
+WebDAV shared folder can be mapped as a drive on Windows, however the default
+settings prevent it. Windows will fail to connect to the server using insecure
+Basic authentication. It will not even display any login dialog. Windows
+requires SSL / HTTPS connection to be used with Basic. If you try to connect
+via Add Network Location Wizard you will get the following error:
 "The folder you entered does not appear to be valid. Please choose another".
-However, you still can connect if you set the following registry key on a client machine:
-HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\WebClient\Parameters\BasicAuthLevel to 2.
-The BasicAuthLevel can be set to the following values:
-    0 - Basic authentication disabled
-    1 - Basic authentication enabled for SSL connections only
-    2 - Basic authentication enabled for SSL connections and for non-SSL connections
+However, you still can connect if you set the following registry key on a
+client machine:
+` + "`HKEY_LOCAL_MACHINE\\SYSTEM\\CurrentControlSet\\Services\\WebClient\\Parameters\\BasicAuthLevel`" + `
+to 2. The BasicAuthLevel can be set to the following values:
+
+` + "```text" + `
+0 - Basic authentication disabled
+1 - Basic authentication enabled for SSL connections only
+2 - Basic authentication enabled for SSL connections and for non-SSL connections
+` + "```" + `
+
 If required, increase the FileSizeLimitInBytes to a higher value.
 Navigate to the Services interface, then restart the WebClient service.
 
 ### Access Office applications on WebDAV
 
-Navigate to following registry HKEY_CURRENT_USER\Software\Microsoft\Office\[14.0/15.0/16.0]\Common\Internet
+Navigate to following registry
+` + "`HKEY_CURRENT_USER\\Software\\Microsoft\\Office\\[14.0/15.0/16.0]\\Common\\Internet`" + `
 Create a new DWORD BasicAuthLevel with value 2.
-    0 - Basic authentication disabled
-    1 - Basic authentication enabled for SSL connections only
-    2 - Basic authentication enabled for SSL and for non-SSL connections
 
-https://learn.microsoft.com/en-us/office/troubleshoot/powerpoint/office-opens-blank-from-sharepoint
+` + "```text" + `
+0 - Basic authentication disabled
+1 - Basic authentication enabled for SSL connections only
+2 - Basic authentication enabled for SSL and for non-SSL connections
+` + "```" + `
+
+<https://learn.microsoft.com/en-us/office/troubleshoot/powerpoint/office-opens-blank-from-sharepoint>
 
 ### Serving over a unix socket
 
 You can serve the webdav on a unix socket like this:
 
-    rclone serve webdav --addr unix:///tmp/my.socket remote:path
+` + "```console" + `
+rclone serve webdav --addr unix:///tmp/my.socket remote:path
+` + "```" + `
 
 and connect to it like this using rclone and the webdav backend:
 
-    rclone --webdav-unix-socket /tmp/my.socket --webdav-url http://localhost lsf :webdav:
+` + "```console" + `
+rclone --webdav-unix-socket /tmp/my.socket --webdav-url http://localhost lsf :webdav:
+` + "```" + `
 
 Note that there is no authentication on http protocol - this is expected to be
 done by the permissions on the socket.
 
-` + libhttp.Help(flagPrefix) + libhttp.TemplateHelp(flagPrefix) + libhttp.AuthHelp(flagPrefix) + vfs.Help() + proxy.Help,
+` + strings.TrimSpace(libhttp.Help(flagPrefix)+libhttp.TemplateHelp(flagPrefix)+libhttp.AuthHelp(flagPrefix)+vfs.Help()+proxy.Help),
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.39",
 		"groups":            "Filter",
