@@ -29,19 +29,19 @@ inaccessible.true
 
 You can use it to tier single object
 
-` + "```sh" + `
+` + "```console" + `
 rclone settier Cool remote:path/file
 ` + "```" + `
 
 Or use rclone filters to set tier on only specific files
 
-` + "```sh" + `
+` + "```console" + `
 rclone --include "*.txt" settier Hot remote:path/dir
 ` + "```" + `
 
 Or just provide remote directory and all files in directory will be tiered
 
-` + "```sh" + `
+` + "```console" + `
 rclone settier tier remote:path/dir
 ` + "```",
 	Annotations: map[string]string{
