@@ -11,7 +11,7 @@ import (
 )
 
 // Starts syslog if configured, returns true if it was started
-func startSysLog() bool {
+func startSysLog(handler *OutputHandler) bool {
 	fs.Fatalf(nil, "--syslog not supported on %s platform", runtime.GOOS)
 	return false
 }
