@@ -12,9 +12,9 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
-// TestListDirSorted is integration testing code in fs/list/list.go
+// testListDirSorted is integration testing code in fs/list/list.go
 // which can't be tested there due to import loops.
-func TestListDirSorted(t *testing.T) {
+func testListDirSorted(t *testing.T, listFn func(ctx context.Context, f fs.Fs, includeAll bool, dir string) (entries fs.DirEntries, err error)) {
 	r := fstest.NewRun(t)
 
 	ctx := context.Background()
@@ -52,20 +52,20 @@ func TestListDirSorted(t *testing.T) {
 		return name
 	}
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, true, "")
+	items, err = listFn(context.Background(), r.Fremote, true, "")
 	require.NoError(t, err)
 	require.Len(t, items, 3)
 	assert.Equal(t, "a.txt", str(0))
 	assert.Equal(t, "sub dir/", str(1))
 	assert.Equal(t, "zend.txt", str(2))
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, false, "")
+	items, err = listFn(context.Background(), r.Fremote, false, "")
 	require.NoError(t, err)
 	require.Len(t, items, 2)
 	assert.Equal(t, "sub dir/", str(0))
 	assert.Equal(t, "zend.txt", str(1))
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, true, "sub dir")
+	items, err = listFn(context.Background(), r.Fremote, true, "sub dir")
 	require.NoError(t, err)
 	require.Len(t, items, 4)
 	assert.Equal(t, "sub dir/hello world", str(0))
@@ -73,7 +73,7 @@ func TestListDirSorted(t *testing.T) {
 	assert.Equal(t, "sub dir/ignore dir/", str(2))
 	assert.Equal(t, "sub dir/sub sub dir/", str(3))
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, false, "sub dir")
+	items, err = listFn(context.Background(), r.Fremote, false, "sub dir")
 	require.NoError(t, err)
 	require.Len(t, items, 2)
 	assert.Equal(t, "sub dir/ignore dir/", str(0))
@@ -82,25 +82,45 @@ func TestListDirSorted(t *testing.T) {
 	// testing ignore file
 	fi.Opt.ExcludeFile = []string{".ignore"}
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, false, "sub dir")
+	items, err = listFn(context.Background(), r.Fremote, false, "sub dir")
 	require.NoError(t, err)
 	require.Len(t, items, 1)
 	assert.Equal(t, "sub dir/sub sub dir/", str(0))
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, false, "sub dir/ignore dir")
+	items, err = listFn(context.Background(), r.Fremote, false, "sub dir/ignore dir")
 	require.NoError(t, err)
 	require.Len(t, items, 0)
 
-	items, err = list.DirSorted(context.Background(), r.Fremote, true, "sub dir/ignore dir")
+	items, err = listFn(context.Background(), r.Fremote, true, "sub dir/ignore dir")
 	require.NoError(t, err)
 	require.Len(t, items, 2)
 	assert.Equal(t, "sub dir/ignore dir/.ignore", str(0))
 	assert.Equal(t, "sub dir/ignore dir/should be ignored", str(1))
 
 	fi.Opt.ExcludeFile = nil
-	items, err = list.DirSorted(context.Background(), r.Fremote, false, "sub dir/ignore dir")
+	items, err = listFn(context.Background(), r.Fremote, false, "sub dir/ignore dir")
 	require.NoError(t, err)
 	require.Len(t, items, 2)
 	assert.Equal(t, "sub dir/ignore dir/.ignore", str(0))
 	assert.Equal(t, "sub dir/ignore dir/should be ignored", str(1))
 }
+
+// TestListDirSorted is integration testing code in fs/list/list.go
+// which can't be tested there due to import loops.
+func TestListDirSorted(t *testing.T) {
+	testListDirSorted(t, list.DirSorted)
+}
+
+// TestListDirSortedFn is integration testing code in fs/list/list.go
+// which can't be tested there due to import loops.
+func TestListDirSortedFn(t *testing.T) {
+	listFn := func(ctx context.Context, f fs.Fs, includeAll bool, dir string) (entries fs.DirEntries, err error) {
+		callback := func(newEntries fs.DirEntries) error {
+			entries = append(entries, newEntries...)
+			return nil
+		}
+		err = list.DirSortedFn(ctx, f, includeAll, dir, callback, nil)
+		return entries, err
+	}
+	testListDirSorted(t, listFn)
+}
