@@ -33,6 +33,8 @@ import (
 	"sync/atomic"
 	"time"
 
+	"slices"
+
 	"github.com/go-git/go-billy/v5"
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/cache"
@@ -65,7 +67,7 @@ type Node interface {
 	Open(flags int) (Handle, error)
 	Truncate(size int64) error
 	Path() string
-	SetSys(interface{})
+	SetSys(any)
 }
 
 // Check interfaces
@@ -177,6 +179,7 @@ type VFS struct {
 	root        *Dir
 	Opt         vfscommon.Options
 	cache       *vfscache.Cache
+	cancel      context.CancelFunc
 	cancelCache context.CancelFunc
 	usageMu     sync.Mutex
 	usageTime   time.Time
@@ -195,8 +198,10 @@ var (
 // DefaultOpt will be used
 func New(f fs.Fs, opt *vfscommon.Options) *VFS {
 	fsDir := fs.NewDir("", time.Now())
+	ctx, cancel := context.WithCancel(context.Background())
 	vfs := &VFS{
-		f: f,
+		f:      f,
+		cancel: cancel,
 	}
 	vfs.inUse.Store(1)
 
@@ -216,7 +221,7 @@ func New(f fs.Fs, opt *vfscommon.Options) *VFS {
 	configName := fs.ConfigString(f)
 	for _, activeVFS := range active[configName] {
 		if vfs.Opt == activeVFS.Opt {
-			fs.Debugf(f, "Re-using VFS from active cache")
+			fs.Debugf(f, "Reusing VFS from active cache")
 			activeVFS.inUse.Add(1)
 			return activeVFS
 		}
@@ -257,6 +262,9 @@ func New(f fs.Fs, opt *vfscommon.Options) *VFS {
 		go vfs.refresh()
 	}
 
+	// Handle supported signals
+	go vfs.signalHandler(ctx)
+
 	// This can take some time so do it after the Pin
 	vfs.SetCacheMode(vfs.Opt.CacheMode)
 
@@ -272,6 +280,27 @@ func (vfs *VFS) refresh() {
 	}
 }
 
+// Reload VFS cache on SIGHUP
+func (vfs *VFS) signalHandler(ctx context.Context) {
+	sigHup := make(chan os.Signal, 1)
+	NotifyOnSigHup(sigHup)
+
+	waiting := true
+	for waiting {
+		select {
+		case <-ctx.Done():
+			waiting = false
+		case <-sigHup:
+			root, err := vfs.Root()
+			if err != nil {
+				fs.Errorf(vfs.Fs(), "Error reading root: %v", err)
+			} else {
+				root.ForgetAll()
+			}
+		}
+	}
+}
+
 // Stats returns info about the VFS
 func (vfs *VFS) Stats() (out rc.Params) {
 	out = make(rc.Params)
@@ -358,13 +387,21 @@ func (vfs *VFS) Shutdown() {
 	for i, activeVFS := range activeVFSes {
 		if activeVFS == vfs {
 			activeVFSes[i] = nil
-			active[configName] = append(activeVFSes[:i], activeVFSes[i+1:]...)
+			active[configName] = slices.Delete(activeVFSes, i, i+1)
 			break
 		}
 	}
 	activeMu.Unlock()
 
 	vfs.shutdownCache()
+
+	if vfs.pollChan != nil {
+		close(vfs.pollChan)
+		vfs.pollChan = nil
+	}
+
+	// Cancel any background go routines
+	vfs.cancel()
 }
 
 // CleanUp deletes the contents of the on disk cache
@@ -893,3 +930,15 @@ func (vfs *VFS) Symlink(oldname, newname string) error {
 	_, err := vfs.CreateSymlink(oldname, newname)
 	return err
 }
+
+// Return true if name represents a metadata file
+//
+// It returns the underlying path
+func (vfs *VFS) isMetadataFile(name string) (rawName string, found bool) {
+	ext := vfs.Opt.MetadataExtension
+	if ext == "" {
+		return name, false
+	}
+	rawName, found = strings.CutSuffix(name, ext)
+	return rawName, found
+}
